# ImageCrawler Plugin Development: Example

There is a example implementation that was created to show you the basics:
[nichtparasoup_placeholders](../../examples/nichtparasoup-imagecrawler-plugin).  
Feel free to look into it for details.

In the following you will have a step by step How-To to talk you through the basics.


## project setup

**TODO**


## implementation

**TODO**


## tests

**TODO**


## examples

**TODO**


## docs

**TODO**
